# Generated by Django 2.1.8 on 2019-04-15 12:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("members", "0010_memberbalance"),
        ("mails", "0007_auto_20180929_0915"),
    ]

    operations = [
        migrations.AddField(
            model_name="email",
            name="balance",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="reminder_mails",
                to="members.MemberBalance",
            ),
        )
    ]
