# Generated by Django 3.1 on 2020-08-18 20:02

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bookkeeping", "0016_auto_20181013_1611"),
    ]

    operations = [
        migrations.AlterField(
            model_name="booking",
            name="data",
            field=models.JSONField(null=True),
        ),
        migrations.AlterField(
            model_name="transaction",
            name="data",
            field=models.JSONField(null=True),
        ),
    ]
