# Generated by Django 2.1.7 on 2019-02-26 11:16

import annoying.fields
import byro.public.models
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    initial = True

    dependencies = [("members", "0009_auto_20180512_1810")]

    operations = [
        migrations.CreateModel(
            name="MemberpageProfile",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "secret_token",
                    models.CharField(
                        blank=True,
                        default=byro.public.models.generate_default_token,
                        max_length=128,
                        null=True,
                    ),
                ),
                (
                    "is_visible_to_members",
                    models.BooleanField(
                        default=False, verbose_name="Consent: Visible to other members"
                    ),
                ),
                (
                    "member",
                    annoying.fields.AutoOneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="profile_memberpage",
                        to="members.Member",
                    ),
                ),
            ],
        )
    ]
