# Generated by Django 1.11.6 on 2017-10-13 14:36

import annoying.fields
from django.db import migrations
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [("sepa", "0001_initial")]

    operations = [
        migrations.AlterField(
            model_name="membersepa",
            name="member",
            field=annoying.fields.AutoOneToOneField(
                on_delete=django.db.models.deletion.PROTECT,
                related_name="profile_sepa",
                to="members.Member",
            ),
        )
    ]
