{% extends "office/base.html" %}
{% load i18n %}
{% load compress %}
{% load static %}

{% block title %}{% blocktrans %}Member page{% endblocktrans %}{% endblock %}
{% block headline %}{% blocktrans %}Personal member page{% endblocktrans %}{% endblock %}

{% block stylesheets%}
    {% compress css %}
        <link rel="stylesheet" type="text/css" href="{% static "public/byro_memberpage.css" %}"/>
    {% endcompress %}
{% endblock %}

{% block content %}
    <div class="alert alert-info">
        {% blocktrans trimmed %}
            Please do not share this page with others – you are seeing it via your personal access token, and sharing it will allow others to act in your name.
        {% endblocktrans %}
    </div>
    {% block public_content %}{% endblock %}
{% endblock %}
