# Generated by Django 1.11.6 on 2017-10-13 14:36

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("members", "0003_membership_membershiptype")]

    operations = [
        migrations.AlterField(
            model_name="member",
            name="address",
            field=models.TextField(blank=True, max_length=300, null=True),
        )
    ]
