# Generated by Django 2.1.1 on 2018-09-29 13:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [("mails", "0007_auto_20180929_0915"), ("common", "0011_logentry")]

    operations = [
        migrations.AddField(
            model_name="configuration",
            name="record_disclosure_template",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="mails.MailTemplate",
            ),
        )
    ]
