# Generated by Django 1.11.6 on 2017-10-12 18:45

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Configuration",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        blank=True, max_length=100, null=True, verbose_name="name"
                    ),
                ),
                (
                    "address",
                    models.CharField(
                        blank=True, max_length=500, null=True, verbose_name="address"
                    ),
                ),
                (
                    "url",
                    models.CharField(
                        blank=True, max_length=200, null=True, verbose_name="url"
                    ),
                ),
                (
                    "language",
                    models.CharField(
                        blank=True, max_length=5, null=True, verbose_name="language"
                    ),
                ),
                (
                    "currency",
                    models.CharField(
                        blank=True, max_length=3, null=True, verbose_name="currency"
                    ),
                ),
                (
                    "registration_form",
                    django.contrib.postgres.fields.jsonb.JSONField(
                        blank=True,
                        null=True,
                        verbose_name="registration form configuration",
                    ),
                ),
            ],
            options={"abstract": False},
        )
    ]
