{% extends "office/base_headline.html" %}
{% load bootstrap4 %}
{% load i18n %}

{% block headline %}{% trans "Add user …" %}{% endblock %}

{% block content %}

    <form method="post">
        {% csrf_token %}
        {% bootstrap_form form layout='horizontal' %}
        <button class="btn btn-success" type="submit">{% trans "Save" %}</button>
    </form>
{% endblock %}
