# Generated by Django 3.1 on 2020-08-20 20:18

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("common", "0017_auto_20200818_2002"),
    ]

    operations = [
        migrations.AddField(
            model_name="configuration",
            name="default_direct_address_name",
            field=models.CharField(
                choices=[
                    ("first", "First part of the name"),
                    ("last", "Last part of the name"),
                ],
                default="first",
                help_text="This is used in emails, for example. You can always override the automatically chosen name if a member has an unusual name.",
                max_length=5,
                verbose_name="Default name when addressing members",
            ),
        ),
        migrations.AddField(
            model_name="configuration",
            name="default_order_name",
            field=models.CharField(
                choices=[
                    ("first", "First part of the name"),
                    ("last", "Last part of the name"),
                ],
                default="last",
                help_text="You can always override the automatic sort order if a member has an unusual name.",
                max_length=5,
                verbose_name="Default sort order",
            ),
        ),
    ]
