# Generated by Django 3.1 on 2020-08-18 20:02

import byro.public.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("public", "0003_auto_20200425_0942"),
    ]

    operations = [
        migrations.AlterField(
            model_name="memberpageprofile",
            name="publication_consent",
            field=models.JSONField(
                blank=True, default=byro.public.models.get_default_consent, null=True
            ),
        ),
    ]
