{% extends "office/member/base.html" %}
{% load bootstrap4 %}
{% load i18n %}

{% block title %}{{ block.super }} :: {% trans "Data" %}{% endblock %}

{% block member_content %}

    <form method='post'>
        {% csrf_token %}
        {% for form in forms %}
            <div class="card member-form-card">
                <div class="card-header">{{ form.instance.form_title }}</div>
                <div class="card-body">
                    {% bootstrap_form form layout='horizontal' %}
                </div>
            </div>
        {% endfor %}
        <div class="card member-form-card">
            <div class="card-body">
                <button class="btn btn-success" type="submit">{% trans "Save" %}</button>
            </div>
        </div>
    </form>
{% endblock %}
