{% extends "office/member/base.html" %}

{% load i18n %}

{% block title %}{{ block.super }} :: {% trans "Mail history" %}{% endblock %}

{% block member_content %}

    <a href="{% url "office:mails.compose" %}?to=special:member:{{ member.pk }}" class="btn btn-success">
        <span class="fa fa-envelope"></span> {% trans "Compose new message …" %}
    </a>

    {% include "office/mails/sent_mails_part.html" with mails=member.emails.all %}
    {% include "office/pagination.html" %}

{% endblock %}
