{% extends "common/log_entry/base.html" %}
{% load i18n %}

{% block log_entry_content %}
    <h5><span class="le-icon"><i class="fa fa-list"></i></span>{% trans "Registration form changed" %}</h5>
{% endblock %}
