# Generated by Django 1.11.4 on 2017-08-12 11:09

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("bookkeeping", "0001_initial")]

    operations = [
        migrations.AlterField(
            model_name="account",
            name="name",
            field=models.CharField(max_length=300, null=True),
        )
    ]
