{% extends "common/log_entry/base.html" %}
{% load i18n %}

{% block log_entry_content %}
    <h5><span class="le-icon"><i class="fa fa-gears"></i></span>{% trans "Settings changed" %}</h5>
    {% if log_entry.data.changes %}
        {% include "common/log_data_changes.html" with changes=log_entry.data.changes %}
    {% endif %}
    {% include "common/log_data.html" with data=log_entry.data %}
{% endblock %}
