# Generated by Django 1.11.4 on 2017-08-12 12:37

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("members", "0001_initial"),
        ("bookkeeping", "0002_auto_20170812_1109"),
    ]

    operations = [
        migrations.AlterField(
            model_name="account",
            name="member",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="accounts",
                to="members.Member",
            ),
        ),
        migrations.AlterUniqueTogether(
            name="account",
            unique_together={("member", "account_category", "name")},
        ),
    ]
