{% extends "office/base_headline.html" %}
{% load i18n %}

{% block headline %}{% trans "Settings" %}{% endblock %}

{% block content %}

    {% block settings_content %}
    {% endblock %}

{% endblock %}
