{% extends "office/member/base.html" %}
{% load bootstrap4 %}
{% load i18n %}

{% block member_content %}

    <form method='post'>
        <div class="card">
            <div class="card-header">
                <b>{% trans "Subject" %}:</b> {{ mail.subject }}
            </div>
        <pre class="card-body">{{ mail.text }}</pre>
            {% csrf_token %}
            <button class="btn btn-success" type="submit">{% trans "Send" %}</button>
        </div>
    </form>


{% endblock %}
