# Generated by Django 1.11.10 on 2018-02-25 20:05

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("common", "0007_auto_20180224_2114")]

    operations = [
        migrations.AddField(
            model_name="configuration",
            name="backoffice_mail",
            field=models.EmailField(
                blank=True,
                max_length=100,
                null=True,
                verbose_name="e-mail of backoffice",
            ),
        )
    ]
