/* FONT PATH
 * -------------------------- */

@font-face {
  font-family: 'FontAwesome';
  src: url(static('vendored/fontawesome/fonts/fontawesome-webfont.eot'));
  src: url(static('vendored/fontawesome/fonts/fontawesome-webfont.eot')) format('embedded-opentype'),
    url(static('vendored/fontawesome/fonts/fontawesome-webfont.woff2')) format('woff2'),
    url(static('vendored/fontawesome/fonts/fontawesome-webfont.woff')) format('woff'),
    url(static('vendored/fontawesome/fonts/fontawesome-webfont.ttf')) format('truetype'),
    url(static('vendored/fontawesome/fonts/fontawesome-webfont.svg')) format('svg');
//  src: url(static('fontawesome/fonts/FontAwesome.otf') format('opentype'); // used when developing fonts
  font-weight: normal;
  font-style: normal;
}

